import { assignNewGraphQueryResult, graphQueryResultSlice, schemaSlice, setSchema } from '../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';

import SemanticSubstrates from './semanticsubstrates';
import { SchemaUtils } from '../../schema/schema-utils';
import { simpleSchemaAirportRaw } from '../../mock-data/schema/simpleAirportRaw';
import { bigMockQueryResults } from '../../mock-data';

const Component: Meta<typeof SemanticSubstrates> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Components/Visualizations/SemanticSubstrates',
  component: SemanticSubstrates,
  decorators: [(story) => <Provider store={Mockstore}>{story()}</Provider>],
};

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

export const TestWithData = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology({
      nodes: [
        {
          name: '1',
          attributes: [{ name: 'a', type: 'string' }],
        },
      ],
      edges: [
        {
          name: '12',
          from: '1',
          to: '1',
          collection: '1c',
          attributes: [{ name: 'a', type: 'string' }],
        },
      ],
    });

    dispatch(setSchema(schema.export()));
    dispatch(
      assignNewGraphQueryResult({
        queryID: '1',
        result: {
          type: 'nodelink',
          payload: {
            nodes: [
              { id: '1/a', attributes: { a: 's1' } },
              { id: '1/b1', attributes: { a: 's1' } },
              { id: '1/b2', attributes: { a: 's1' } },
              { id: '1/b3', attributes: { a: 's1' } },
            ],
            edges: [
              { id: '12/z1', from: '1/b1', to: '1/a', attributes: { a: 's1' } },
              // { from: 'b2', to: 'a', attributes: {} },
              // { from: 'b3', to: 'a', attributes: {} },
              { id: '12/z1', from: '1/a', to: '1/b1', attributes: { a: 's1' } },
            ],
          },
        },
      })
    );
  },
};

export const TestWithAirport = {
  args: {
    loading: false,
    rowHeight: 30,
    hyperedgeColumnWidth: 30,
    gapBetweenRanges: 3,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaAirportRaw);

    dispatch(setSchema(schema.export()));
    dispatch(
      assignNewGraphQueryResult({
        queryID: '1',
        result: { type: 'nodelink', payload: bigMockQueryResults },
      })
    );
  },
};

export default Component;
